@@ -1,6 +1,6 @@
 
 rule_class <- function(x) {
-  structure(x, class = c("rule", "character"))
+  structure(x, class = c("rule", "ansi_string", "character"))
 }
 
 capture_messages <- function(expr) {
@@ -21,8 +21,9 @@ capt00 <- function(expr) {
   capt(expr, print_it = FALSE)
 }
 
-capt0 <- function(expr) {
-  capture_messages(expr)
+capt0 <- function(expr, strip_style = FALSE) {
+  out <- capture_messages(expr)    
+  if  (strip_style) ansi_strip(out) else out
 }
 
 capt_cat <- function(expr) {
